import { SDKConfig } from '@commandbar/internal/client/SDKConfig';
import { FormFactor, MetaAttributes } from '@commandbar/internal/client/CommandBarClientSDK';
import { ChecklistEvent, ChecklistItemEvent, EngagementType, NudgeEvent, PreviewEvent, HelpHubEvent, HelpHubDocEvent, EventType, SurveyResponseEvent, ChatHistory, ClientErrorEvent } from './EventHandler';
export declare enum EVENT_TYPE {
    Track = "t",
    Identify = "i",
    Log = "l",
    Availability = "a",
    Error = "e"
}
export type EVENT_NAME = 'Identify' | 'New session' | 'End session' | 'Load Performance' | 'New search' | 'Exited' | 'Search input' | 'Onboarding tooltip shown' | 'Tooltip shown' | 'Onboarding started' | 'Onboarding exited' | 'Onboarding completed' | 'Abandoned search' | 'No results for query' | 'Command suggestion' | 'Command execution' | 'Unavailable shortcut' | 'Clicked branding' | 'Survey response' | 'Client-Error' | 'Internal-Error' | 'Internal-Event' | 'Sentry-Event' | 'User changed shortcut' | 'Preview shown' | 'Next step selected' | 'Preview link opened' | 'Preview engagement' | 'Nudge shown' | 'Nudge clicked' | 'Nudge completed' | 'Nudge dismissed' | 'Nudge snoozed' | 'Questlist shown' | 'Questlist engagement' | 'Questlist item engagement' | 'HelpHub opened' | 'HelpHub closed' | 'HelpHub unminimized' | 'HelpHub minimized' | 'HelpHub doc opened' | 'HelpHub doc closed' | 'HelpHub doc engagement' | 'HelpHub engagement' | 'No chat response';
export type EVENT_CATEGORY = 'user' | 'internal' | 'error' | 'unknown';
export declare const eventAttributes: readonly ["command", "commandText", "inputText", "inputText[*]", "length", "message", "record", "resource", "session", "url", "placeholder", "selections", "shortcut", "text", "user_attributes"];
export interface IEventAttributes {
    type: EventType;
    isAdmin: boolean;
    command: string | number;
    commands: number[];
    commandText: string;
    nudge: NudgeEvent['nudge'];
    questlist: ChecklistEvent['questlist'];
    questlist_item: ChecklistItemEvent['questlist_item'];
    preview: PreviewEvent['preview'];
    helpHub: HelpHubEvent['helpHub'];
    helpHubDoc: HelpHubDocEvent['helpHubDoc'];
    engagement_type: EngagementType;
    error: Omit<ClientErrorEvent, 'type'>;
    category: string | number | null;
    categoryText: string | null;
    source: string;
    inputText: string;
    ['inputText[*]']: string;
    length: number;
    message: string;
    description: string;
    record: string;
    resource: string;
    session: string;
    placeholder: string;
    selections: Record<string, any>;
    shortcut: string[] | boolean;
    text: string;
    url: string;
    user_attributes: string;
    user_event: boolean;
    formFactor: FormFactor['type'];
    engagementType: string;
    response: SurveyResponseEvent['response'];
    chatHistory: ChatHistory;
}
export type EventAttributeKey = keyof IEventAttributes;
export interface IEventPayload {
    context: {
        page: {
            path?: string;
            title?: string;
            url?: string;
            search?: string;
        };
        meta: MetaAttributes;
        userAgent?: string;
        groupId?: string;
        cbSource: SDKConfig;
    };
    userType: 'admin' | 'likely-admin' | 'end_user';
    type: EVENT_TYPE;
    attrs: Partial<IEventAttributes>;
    name?: string;
    id: string | null | undefined;
    session: string;
    search?: string;
    reportToSegment: boolean;
    fingerprint?: string;
    clientEventTimestamp: string;
    clientFlushedTimestamp?: string;
}
export type DenyListCategory = 'commands' | 'records' | 'urls' | 'user_inputs_and_deadends' | 'help_hub_search';
