import { TUpdateEditorRouteDetails } from '../util/dispatchCustomEvent';
import { CommandBarClientSDK, InstanceAttributes, MetaAttributes, Metadata, ProductConfig, ProductDebugOptions } from './CommandBarClientSDK';
import type { Hub } from '@sentry/browser';
import { _configuration, _configure, _configUser, _dispose, _disposed, _eventSubscriptions, _userProperties, _isProxy, _loadEditor, _orgConfig, _perf, _programmaticTheme, _reload, _reloadCommands, _reloadOrganization, _reloadPlaceholders, _reloadNudges, _reloadHelpHub, _startNudgeDebug, _showNudgeStepMock, _closeNudgeMocks, _stopChecklistPreview, _stopNudgeDebug, _reloadChecklists, _report, _search, _sentry, _setDashboard, _setPreviewMode, _setTestMode, _showGuide, _showMessage, _user, _instanceAttributes, _setEditorVisible, _shareConfig, _shareContextSettings, _shareProgrammaticCommands, _metaAttributes, _previewChecklist, _shareEditorRouteWithBar, _fingerprint, _updateEditorRoute, _startDebug, _stopDebug, _previewRecommendationSet, _previewCopilotSettings, _stopRecommendationSetPreview, _getDebugSnapshot, _updateEditorPreviewDevice, _getEditorPreviewDevice, _shareTrackedEvents, _setThemeV2, _showWidgetTableau } from './symbols';
import { SDKConfig } from './SDKConfig';
import { IChecklist, ICommandType, IConfigType, ICopilotSettingsPreviewType, INudgeType, IRecommendationSet, IRecordSettingsByContextKey, IThemeV2Type } from '../middleware/types';
import { OrgConfig } from './OrgConfig';
import { DeviceType } from '../util/operatingSystem';
import type { EVENT_NAME } from '@commandbar/commandbar/shared/services/analytics/types';
import type { EventSubscriber } from '@commandbar/commandbar/shared/services/analytics/EventHandler';
export type { SDKConfig } from './SDKConfig';
export declare const _reloadTargets: string[];
export interface CommandBarInternalSDK {
    [_instanceAttributes]: InstanceAttributes;
    [_metaAttributes]: MetaAttributes;
    [_perf]: boolean;
    [_programmaticTheme]: string | undefined;
    [_sentry]: Hub | undefined;
    [_search]: string;
    [_user]: string | null | undefined;
    [_fingerprint]: string | undefined;
    [_userProperties]: Metadata | undefined;
    [_eventSubscriptions]: Map<symbol, EventSubscriber> | undefined;
    /** @deprecated */
    readonly [_configure]: (uuid: string) => void;
    readonly [_configuration]: SDKConfig;
    readonly [_configUser]: () => Promise<void>;
    readonly [_dispose]: () => void;
    readonly [_disposed]: false;
    readonly [_isProxy]: false;
    readonly [_loadEditor]: () => void;
    readonly [_shareEditorRouteWithBar]: (path: string) => void;
    readonly [_updateEditorPreviewDevice]: (device: DeviceType) => void;
    readonly [_getEditorPreviewDevice]: () => DeviceType;
    readonly [_orgConfig]: OrgConfig;
    readonly [_reload]: (reloadTargets: (typeof _reloadTargets)[number][]) => void;
    readonly [_reloadCommands]: (preLoadedConfig?: IConfigType) => void;
    readonly [_reloadOrganization]: (preLoadedConfig?: IConfigType) => void;
    readonly [_reloadPlaceholders]: (preLoadedConfig?: IConfigType) => void;
    readonly [_reloadNudges]: (preLoadedConfig?: IConfigType) => void;
    readonly [_reloadHelpHub]: (preLoadedConfig?: IConfigType) => void;
    readonly [_previewRecommendationSet]: (data: {
        recommendationSet?: IRecommendationSet;
    }) => void;
    readonly [_previewCopilotSettings]: (data: {
        settings: ICopilotSettingsPreviewType;
    }) => void;
    readonly [_stopRecommendationSetPreview]: () => void;
    readonly [_startNudgeDebug]: (data: {
        nudge: INudgeType;
    }) => void;
    readonly [_showNudgeStepMock]: (data: {
        nudge: INudgeType;
        stepIndex: number;
        forceOpen?: boolean;
    }) => void;
    readonly [_closeNudgeMocks]: () => void;
    readonly [_stopChecklistPreview]: () => void;
    readonly [_stopNudgeDebug]: (data: {
        index?: number;
    }) => void;
    readonly [_previewChecklist]: (data: {
        checklist: IChecklist;
        clearData?: boolean;
    }) => void;
    readonly [_reloadChecklists]: () => void;
    readonly [_setThemeV2]: (themeV2: IThemeV2Type, mode: 'light_mode' | 'dark_mode') => void;
    readonly [_showWidgetTableau]: (show: boolean) => void;
    /** @deprecated  */
    readonly [_report]: (event: EVENT_NAME, data?: Metadata) => void;
    /** @deprecated  */
    readonly [_setDashboard]: (element: HTMLElement) => void;
    readonly [_setPreviewMode]: (on: boolean) => void;
    readonly [_setTestMode]: (on: boolean) => void;
    readonly [_setEditorVisible]: (visible: boolean) => void;
    readonly [_shareContextSettings]: () => {
        local: IRecordSettingsByContextKey;
        server: IRecordSettingsByContextKey;
    };
    readonly [_shareConfig]: () => any;
    readonly [_shareProgrammaticCommands]: () => ICommandType[];
    readonly [_shareTrackedEvents]: () => {
        trackedEvents: string[];
    };
    readonly [_startDebug]: (data: ProductDebugOptions) => void;
    readonly [_stopDebug]: (product?: ProductConfig[number]) => void;
    readonly [_getDebugSnapshot]: (data?: {
        nudgeId?: INudgeType['id'];
        stepIndex?: number;
    }) => void;
    readonly [_updateEditorRoute]: (data: TUpdateEditorRouteDetails) => void;
    /** @deprecated */
    readonly [_showGuide]: (eventName: string, preview?: boolean) => void;
    /** @deprecated */
    readonly [_showMessage]: (eventName: string, preview?: boolean) => void;
}
export type CommandBarSDK = CommandBarInternalSDK & CommandBarClientSDK;
