import * as t from 'io-ts';
export declare const BillingProfileV: t.TypeC<{
    organization: t.StringC;
    tier: t.StringC;
    discount_cents: t.NumberC;
    name: t.StringC;
    invoice_description: t.StringC;
    customer_id: t.UnionC<[t.StringC, t.NullC]>;
    publishable_key: t.StringC;
    balance: t.UnionC<[t.NumberC, t.NullC]>;
    currency: t.UnionC<[t.StringC, t.NullC]>;
    on_free_trial: t.BooleanC;
    free_trial_end_date: t.UnionC<[t.StringC, t.NullC]>;
    appsumo_invoice_item_id: t.UnionC<[t.StringC, t.NullC]>;
}>;
export declare const StripInfoV: t.IntersectionC<[t.TypeC<{
    invoice_date_start: t.UnionC<[t.StringC, t.NullC]>;
    invoice_date_end: t.UnionC<[t.StringC, t.NullC]>;
}>, t.PartialC<{}>]>;
export declare const UsageV: t.IntersectionC<[t.TypeC<{
    helphub_docs_limit: t.NumberC;
    helphub_docs_usage: t.NumberC;
    helphub_message_limit: t.NumberC;
    helphub_message_usage: t.NumberC;
    commands_live_limit: t.NumberC;
    commands_live_usage: t.NumberC;
    nudges_live_limit: t.NumberC;
    nudges_live_usage: t.NumberC;
    questlists_live_limit: t.NumberC;
    questlists_live_usage: t.NumberC;
}>, t.PartialC<{}>]>;
export declare class Billing {
    static readStripeInfo: (params?: Record<string, string> | undefined, callbacks?: {
        onSuccess?: (() => void) | undefined;
        onError?: ((err: string) => void) | undefined;
    } | undefined) => Promise<{
        invoice_date_start: string | null;
        invoice_date_end: string | null;
    } & {}>;
    static readUsage: (params?: Record<string, string> | undefined, callbacks?: {
        onSuccess?: (() => void) | undefined;
        onError?: ((err: string) => void) | undefined;
    } | undefined) => Promise<{
        helphub_docs_limit: number;
        helphub_docs_usage: number;
        helphub_message_limit: number;
        helphub_message_usage: number;
        commands_live_limit: number;
        commands_live_usage: number;
        nudges_live_limit: number;
        nudges_live_usage: number;
        questlists_live_limit: number;
        questlists_live_usage: number;
    } & {}>;
    static readProfile: (params?: Record<string, string> | undefined, callbacks?: {
        onSuccess?: (() => void) | undefined;
        onError?: ((err: string) => void) | undefined;
    } | undefined) => Promise<{
        organization: string;
        tier: string;
        discount_cents: number;
        name: string;
        invoice_description: string;
        customer_id: string | null;
        publishable_key: string;
        balance: number | null;
        currency: string | null;
        on_free_trial: boolean;
        free_trial_end_date: string | null;
        appsumo_invoice_item_id: string | null;
    }>;
}
